Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(28)

Unified Diff: chrome/test/base/ui_test_utils.h

Issue 10698068: chrome: Put browser_navigator.h into chrome namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: already in chrome namespace Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/base/in_process_browser_test.cc ('k') | chrome/test/base/ui_test_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/base/ui_test_utils.h
diff --git a/chrome/test/base/ui_test_utils.h b/chrome/test/base/ui_test_utils.h
index a2ec81112801aeb2c032638ae6b3eb61bb8bb813..04ab3abf9ac81fa57c7a8a8a88c72437e0932386 100644
--- a/chrome/test/base/ui_test_utils.h
+++ b/chrome/test/base/ui_test_utils.h
@@ -20,9 +20,9 @@
#include "chrome/browser/ui/view_ids.h"
#include "chrome/test/automation/dom_element_proxy.h"
#include "content/public/browser/browser_thread.h"
+#include "content/public/browser/notification_details.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
-#include "content/public/browser/notification_details.h"
#include "content/public/browser/notification_source.h"
#include "testing/gtest/include/gtest/gtest.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebInputEvent.h"
@@ -54,7 +54,7 @@ class SkBitmap;
class TabContents;
class TemplateURLService;
-namespace browser {
+namespace chrome {
struct NavigateParams;
}
@@ -131,11 +131,11 @@ void OpenURLOffTheRecord(Profile* profile, const GURL& url);
// Performs the provided navigation process, blocking until the navigation
// finishes. May change the params in some cases (i.e. if the navigation
-// opens a new browser window). Uses browser::Navigate.
-void NavigateToURL(browser::NavigateParams* params);
+// opens a new browser window). Uses chrome::Navigate.
+void NavigateToURL(chrome::NavigateParams* params);
// Navigates the selected tab of |browser| to |url|, blocking until the
// navigation finishes. Uses Browser::OpenURL --> browser::Navigate.
void NavigateToURL(Browser* browser, const GURL& url);
// Navigates the specified tab of |browser| to |url|, blocking until the
« no previous file with comments | « chrome/test/base/in_process_browser_test.cc ('k') | chrome/test/base/ui_test_utils.cc » ('j') | no next file with comments »
@@ -131,11 +131,11 @@ void OpenURLOffTheRecord(Profile* profile, const GURL& url);
// Navigates the selected tab of |browser| to |url|, blocking until the
-// navigation finishes. Uses Browser::OpenURL --> browser::Navigate.
+// navigation finishes. Uses Browser::OpenURL --> chrome::Navigate.
void NavigateToURL(Browser* browser, const GURL& url);
// Navigates the specified tab of |browser| to |url|, blocking until the

Powered by Google App Engine
This is Rietveld 408576698